pub enum DecodeError {
InputIsEmpty,
OutputTooShort,
Malformed {
read: usize,
write: usize,
length: usize,
offset: usize,
},
Other {
msg: Cow<'static, str>,
},
}Variants
InputIsEmpty
Input buffer is empty.
OutputTooShort
The length of the output buffer is too short.
If this error is returned, it is guaranteed that the decoder is consuming the input buffer.
Malformed
Malformed byte sequence is found.
The input and output buffer have consumed read and write bytes respectively.
Malformed sequence occurs input[read-length-offset..read-offset].
Other
Other errors.