pub enum EncodeError {
InputIsEmpty,
OutputTooShort,
Unmappable {
read: usize,
write: usize,
c: char,
},
Other {
msg: Cow<'static, str>,
},
}Variants
InputIsEmpty
Input buffer is empty.
OutputTooShort
The length of the output buffer is too short.
If this error is returned, it is guaranteed that the encoder is consuming the input buffer.
Unmappable
A UTF-8 character c cannot map any codepoints of the target encoding.
The input and output buffer have consumed read and write bytes respectively.
read includes the length of c. Thus, the correctly read length is read - c.len_utf8().
write does not include the length of c because encoder cannot write unmapped characters.
Other
Other errors.