register_encoding_alias

Function register_encoding_alias 

pub fn register_encoding_alias(
    alias: &'static str,
    real: &'static str,
) -> Option<&'static str>
Register alias as an alias for the encoding name real.
If alias is already an alias for another encoding name, overwrite it and return the encoding name before the overwrite.

It is assumed that real names and aliases will be linked based on the IANA list, but this is not required.
However, since aliases do not redirect multiple times, real must be the name registered with the encoder/decoder.

If an encoding name becomes both a real name and an alias, searches may not work properly.

Reference: Charcter sets registered by IANA